@@ -1,26 +1,24 @@
 # encoding: utf-8
 
-"""
-Chart shape-related objects such as Chart.
-"""
+"""Chart-related objects such as Chart and ChartTitle."""
 
-from __future__ import absolute_import, print_function, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-from collections import Sequence
-
-from .axis import CategoryAxis, DateAxis, ValueAxis
-from .legend import Legend
-from .plot import PlotFactory, PlotTypeInspector
-from .series import SeriesCollection
-from ..shared import PartElementProxy
-from ..util import lazyproperty
-from .xmlwriter import SeriesXmlRewriterFactory
+from pptx.chart.axis import CategoryAxis, DateAxis, ValueAxis
+from pptx.chart.legend import Legend
+from pptx.chart.plot import PlotFactory, PlotTypeInspector
+from pptx.chart.series import SeriesCollection
+from pptx.chart.xmlwriter import SeriesXmlRewriterFactory
+from pptx.compat import Sequence
+from pptx.dml.chtfmt import ChartFormat
+from pptx.shared import ElementProxy, PartElementProxy
+from pptx.text.text import Font, TextFrame
+from pptx.util import lazyproperty
 
 
 class Chart(PartElementProxy):
-    """
-    A chart object.
-    """
+    """A chart object."""
+
     def __init__(self, chartSpace, chart_part):
         super(Chart, self).__init__(chartSpace, chart_part)
         self._chartSpace = chartSpace
@@ -44,7 +42,7 @@ class Chart(PartElementProxy):
         if valAx_lst:
             return ValueAxis(valAx_lst[0])
 
-        raise ValueError('chart has no category axis')
+        raise ValueError("chart has no category axis")
 
     @property
     def chart_style(self):
@@ -68,6 +66,17 @@ class Chart(PartElementProxy):
             return
         self._chartSpace._add_style(val=value)
 
+    @property
+    def chart_title(self):
+        """A |ChartTitle| object providing access to title properties.
+
+        Calling this property is destructive in the sense it adds a chart
+        title element (`c:title`) to the chart XML if one is not already
+        present. Use :attr:`has_title` to test for presence of a chart title
+        non-destructively.
+        """
+        return ChartTitle(self._element.get_or_add_title())
+
     @property
     def chart_type(self):
         """
@@ -79,6 +88,17 @@ class Chart(PartElementProxy):
         first_plot = self.plots[0]
         return PlotTypeInspector.chart_type(first_plot)
 
+    @lazyproperty
+    def font(self):
+        """Font object controlling text format defaults for this chart."""
+        defRPr = (
+            self._chartSpace.get_or_add_txPr()
+            .p_lst[0]
+            .get_or_add_pPr()
+            .get_or_add_defRPr()
+        )
+        return Font(defRPr)
+
     @property
     def has_legend(self):
         """
@@ -93,6 +113,29 @@ class Chart(PartElementProxy):
     def has_legend(self, value):
         self._chartSpace.chart.has_legend = bool(value)
 
+    @property
+    def has_title(self):
+        """Read/write boolean, specifying whether this chart has a title.
+
+        Assigning |True| causes a title to be added if not already present.
+        Assigning |False| removes any existing title along with its text and
+        settings.
+        """
+        title = self._chartSpace.chart.title
+        if title is None:
+            return False
+        return True
+
+    @has_title.setter
+    def has_title(self, value):
+        chart = self._chartSpace.chart
+        if bool(value) is False:
+            chart._remove_title()
+            autoTitleDeleted = chart.get_or_add_autoTitleDeleted()
+            autoTitleDeleted.val = True
+            return
+        chart.get_or_add_title()
+
     @property
     def legend(self):
         """
@@ -149,7 +192,7 @@ class Chart(PartElementProxy):
         """
         valAx_lst = self._chartSpace.valAx_lst
         if not valAx_lst:
-            raise ValueError('chart has no value axis')
+            raise ValueError("chart has no value axis")
 
         idx = 1 if len(valAx_lst) > 1 else 0
         return ValueAxis(valAx_lst[idx])
@@ -163,6 +206,63 @@ class Chart(PartElementProxy):
         return self.part.chart_workbook
 
 
+class ChartTitle(ElementProxy):
+    """Provides properties for manipulating a chart title."""
+
+    # This shares functionality with AxisTitle, which could be factored out
+    # into a base class, perhaps pptx.chart.shared.BaseTitle. I suspect they
+    # actually differ in certain fuller behaviors, but at present they're
+    # essentially identical.
+
+    __slots__ = ("_title", "_format")
+
+    def __init__(self, title):
+        super(ChartTitle, self).__init__(title)
+        self._title = title
+
+    @lazyproperty
+    def format(self):
+        """|ChartFormat| object providing access to line and fill formatting.
+
+        Return the |ChartFormat| object providing shape formatting properties
+        for this chart title, such as its line color and fill.
+        """
+        return ChartFormat(self._title)
+
+    @property
+    def has_text_frame(self):
+        """Read/write Boolean specifying whether this title has a text frame.
+
+        Return |True| if this chart title has a text frame, and |False|
+        otherwise. Assigning |True| causes a text frame to be added if not
+        already present. Assigning |False| causes any existing text frame to
+        be removed along with its text and formatting.
+        """
+        if self._title.tx_rich is None:
+            return False
+        return True
+
+    @has_text_frame.setter
+    def has_text_frame(self, value):
+        if bool(value) is False:
+            self._title._remove_tx()
+            return
+        self._title.get_or_add_tx_rich()
+
+    @property
+    def text_frame(self):
+        """|TextFrame| instance for this chart title.
+
+        Return a |TextFrame| instance allowing read/write access to the text
+        of this chart title and its text formatting properties. Accessing this
+        property is destructive in the sense it adds a text frame if one is
+        not present. Use :attr:`has_text_frame` to test for the presence of
+        a text frame non-destructively.
+        """
+        rich = self._title.get_or_add_tx_rich()
+        return TextFrame(rich, self)
+
+
 class _Plots(Sequence):
     """
     The sequence of plots in a chart, such as a bar plot or a line plot. Most
@@ -170,6 +270,7 @@ class _Plots(Sequence):
     types are displayed in a single set of axes, like a bar plot with
     a superimposed line plot.
     """
+
     def __init__(self, plotArea, chart):
         super(_Plots, self).__init__()
         self._plotArea = plotArea
