@@ -2,9 +2,7 @@
 
 """MediaPart and related objects."""
 
-from __future__ import (
-    absolute_import, division, print_function, unicode_literals
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 import hashlib
 
