@@ -4,9 +4,7 @@
 Main presentation object.
 """
 
-from __future__ import (
-    absolute_import, division, print_function, unicode_literals
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from .shared import PartElementProxy
 from .slide import SlideMasters, Slides
@@ -19,7 +17,7 @@ class Presentation(PartElementProxy):
     directly. Use :func:`pptx.Presentation` to open or create a presentation.
     """
 
-    __slots__ = ('_slide_masters', '_slides')
+    __slots__ = ("_slide_masters", "_slides")
 
     @property
     def core_properties(self):
@@ -29,6 +27,15 @@ class Presentation(PartElementProxy):
         """
         return self.part.core_properties
 
+    @property
+    def notes_master(self):
+        """
+        Instance of |NotesMaster| for this presentation. If the presentation
+        does not have a notes master, one is created from a default template
+        and returned. The same single instance is returned on each call.
+        """
+        return self.part.notes_master
+
     def save(self, file):
         """
         Save this presentation to *file*, where *file* can be either a path
