@@ -1,23 +1,21 @@
 # encoding: utf-8
 
-"""
-Base shape-related objects such as BaseShape.
-"""
+"""Base shape-related objects such as BaseShape."""
 
-from __future__ import (
-    absolute_import, division, print_function, unicode_literals
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-from ..action import ActionSetting
-from ..shared import ElementProxy
-from ..util import lazyproperty
+from pptx.action import ActionSetting
+from pptx.dml.effect import ShadowFormat
+from pptx.shared import ElementProxy
+from pptx.util import lazyproperty
 
 
 class BaseShape(object):
+    """Base class for shape objects.
+
+    Subclasses include |Shape|, |Picture|, and |GraphicFrame|.
     """
-    Base class for shape objects, including |Shape|, |Picture|, and
-    |GraphicFrame|.
-    """
+
     def __init__(self, shape_elm, parent):
         super(BaseShape, self).__init__()
         self._element = shape_elm
@@ -40,10 +38,13 @@ class BaseShape(object):
 
     @lazyproperty
     def click_action(self):
-        """
-        An |ActionSetting| instance providing access to the mouse click
-        behaviors defined on this shape. An |ActionSetting| object is always
-        returned, even when no click behavior is defined on the shape.
+        """|ActionSetting| instance providing access to click behaviors.
+
+        Click behaviors are hyperlink-like behaviors including jumping to
+        a hyperlink (web page) or to another slide in the presentation. The
+        click action is that defined on the overall shape, not a run of text
+        within the shape. An |ActionSetting| object is always returned, even
+        when no click behavior is defined on the shape.
         """
         cNvPr = self._element._nvXxPr.cNvPr
         return ActionSetting(cNvPr, self)
@@ -149,7 +150,7 @@ class BaseShape(object):
         |ValueError| on access if the shape is not a placeholder.
         """
         if not self.is_placeholder:
-            raise ValueError('shape is not a placeholder')
+            raise ValueError("shape is not a placeholder")
         return _PlaceholderFormat(self._element.ph)
 
     @property
@@ -165,6 +166,16 @@ class BaseShape(object):
     def rotation(self, value):
         self._element.rot = value
 
+    @lazyproperty
+    def shadow(self):
+        """|ShadowFormat| object providing access to shadow for this shape.
+
+        A |ShadowFormat| object is always returned, even when no shadow is
+        explicitly defined on this shape (i.e. it inherits its shadow
+        behavior).
+        """
+        return ShadowFormat(self._element.spPr)
+
     @property
     def shape_id(self):
         """Read-only positive integer identifying this shape.
@@ -217,6 +228,7 @@ class _PlaceholderFormat(ElementProxy):
     a placeholder shape, provides properties specific to placeholders, such
     as the placeholder type.
     """
+
     @property
     def element(self):
         """
