@@ -2,9 +2,7 @@
 
 """Test suite for pptx.slide module"""
 
-from __future__ import (
-    absolute_import, division, print_function, unicode_literals
-)
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 import pytest
 
@@ -17,23 +15,35 @@ from pptx.presentation import Presentation
 from pptx.shapes.base import BaseShape
 from pptx.shapes.placeholder import LayoutPlaceholder, NotesSlidePlaceholder
 from pptx.shapes.shapetree import (
-    LayoutPlaceholders, LayoutShapes, MasterPlaceholders, MasterShapes,
-    NotesSlidePlaceholders, NotesSlideShapes, SlidePlaceholders, SlideShapes
+    LayoutPlaceholders,
+    LayoutShapes,
+    MasterPlaceholders,
+    MasterShapes,
+    NotesSlidePlaceholders,
+    NotesSlideShapes,
+    SlidePlaceholders,
+    SlideShapes,
 )
 from pptx.slide import (
-    _Background, _BaseMaster, _BaseSlide, NotesMaster, NotesSlide, Slide,
-    SlideLayout, SlideLayouts, SlideMaster, SlideMasters, Slides
+    _Background,
+    _BaseMaster,
+    _BaseSlide,
+    NotesMaster,
+    NotesSlide,
+    Slide,
+    SlideLayout,
+    SlideLayouts,
+    SlideMaster,
+    SlideMasters,
+    Slides,
 )
 from pptx.text.text import TextFrame
 
 from .unitutil.cxml import element, xml
-from .unitutil.mock import (
-    call, class_mock, instance_mock, method_mock, property_mock
-)
+from .unitutil.mock import call, class_mock, instance_mock, method_mock, property_mock
 
 
 class Describe_BaseSlide(object):
-
     def it_knows_its_name(self, name_get_fixture):
         base_slide, expected_value = name_get_fixture
         assert base_slide.name == expected_value
@@ -55,29 +65,30 @@ class Describe_BaseSlide(object):
 
     @pytest.fixture
     def background_fixture(self, _Background_, background_):
-        sld = element('p:sld/p:cSld')
+        sld = element("p:sld/p:cSld")
         slide = _BaseSlide(sld, None)
-        cSld = sld.xpath('//p:cSld')[0]
+        cSld = sld.xpath("//p:cSld")[0]
         _Background_.return_value = background_
         return slide, _Background_, cSld, background_
 
-    @pytest.fixture(params=[
-        ('p:sld/p:cSld',              ''),
-        ('p:sld/p:cSld{name=Foobar}', 'Foobar'),
-    ])
+    @pytest.fixture(
+        params=[("p:sld/p:cSld", ""), ("p:sld/p:cSld{name=Foobar}", "Foobar")]
+    )
     def name_get_fixture(self, request):
         sld_cxml, expected_name = request.param
         base_slide = _BaseSlide(element(sld_cxml), None)
         return base_slide, expected_name
 
-    @pytest.fixture(params=[
-        ('p:sld/p:cSld',           'foo', 'p:sld/p:cSld{name=foo}'),
-        ('p:sld/p:cSld{name=foo}', 'bar', 'p:sld/p:cSld{name=bar}'),
-        ('p:sld/p:cSld{name=bar}', '',    'p:sld/p:cSld'),
-        ('p:sld/p:cSld{name=bar}', None,  'p:sld/p:cSld'),
-        ('p:sld/p:cSld',           '',    'p:sld/p:cSld'),
-        ('p:sld/p:cSld',           None,  'p:sld/p:cSld'),
-    ])
+    @pytest.fixture(
+        params=[
+            ("p:sld/p:cSld", "foo", "p:sld/p:cSld{name=foo}"),
+            ("p:sld/p:cSld{name=foo}", "bar", "p:sld/p:cSld{name=bar}"),
+            ("p:sld/p:cSld{name=bar}", "", "p:sld/p:cSld"),
+            ("p:sld/p:cSld{name=bar}", None, "p:sld/p:cSld"),
+            ("p:sld/p:cSld", "", "p:sld/p:cSld"),
+            ("p:sld/p:cSld", None, "p:sld/p:cSld"),
+        ]
+    )
     def name_set_fixture(self, request):
         xSld_cxml, new_value, expected_cxml = request.param
         base_slide = _BaseSlide(element(xSld_cxml), None)
@@ -88,7 +99,7 @@ class Describe_BaseSlide(object):
 
     @pytest.fixture
     def _Background_(self, request):
-        return class_mock(request, 'pptx.slide._Background')
+        return class_mock(request, "pptx.slide._Background")
 
     @pytest.fixture
     def background_(self, request):
@@ -96,15 +107,12 @@ class Describe_BaseSlide(object):
 
 
 class Describe_BaseMaster(object):
-
     def it_is_a_BaseSlide_subclass(self, subclass_fixture):
         base_master = subclass_fixture
         assert isinstance(base_master, _BaseSlide)
 
     def it_provides_access_to_its_placeholders(self, placeholders_fixture):
-        base_master, MasterPlaceholders_, spTree, placeholders_ = (
-            placeholders_fixture
-        )
+        base_master, MasterPlaceholders_, spTree, placeholders_ = placeholders_fixture
         placeholders = base_master.placeholders
         MasterPlaceholders_.assert_called_once_with(spTree, base_master)
         assert placeholders is placeholders_
@@ -119,16 +127,16 @@ class Describe_BaseMaster(object):
 
     @pytest.fixture
     def placeholders_fixture(self, MasterPlaceholders_, placeholders_):
-        master_element = element('p:sldMaster/p:cSld/p:spTree')
+        master_element = element("p:sldMaster/p:cSld/p:spTree")
         base_master = _BaseMaster(master_element, None)
-        spTree = master_element.xpath('//p:spTree')[0]
+        spTree = master_element.xpath("//p:spTree")[0]
         return base_master, MasterPlaceholders_, spTree, placeholders_
 
     @pytest.fixture
     def shapes_fixture(self, MasterShapes_, shapes_):
-        master_element = element('p:sldMaster/p:cSld/p:spTree')
+        master_element = element("p:sldMaster/p:cSld/p:spTree")
         base_master = _BaseMaster(master_element, None)
-        spTree = master_element.xpath('//p:spTree')[0]
+        spTree = master_element.xpath("//p:spTree")[0]
         return base_master, MasterShapes_, spTree, shapes_
 
     @pytest.fixture
@@ -140,15 +148,12 @@ class Describe_BaseMaster(object):
     @pytest.fixture
     def MasterPlaceholders_(self, request, placeholders_):
         return class_mock(
-            request, 'pptx.slide.MasterPlaceholders',
-            return_value=placeholders_
+            request, "pptx.slide.MasterPlaceholders", return_value=placeholders_
         )
 
     @pytest.fixture
     def MasterShapes_(self, request, shapes_):
-        return class_mock(
-            request, 'pptx.slide.MasterShapes', return_value=shapes_
-        )
+        return class_mock(request, "pptx.slide.MasterShapes", return_value=shapes_)
 
     @pytest.fixture
     def placeholders_(self, request):
@@ -160,7 +165,6 @@ class Describe_BaseMaster(object):
 
 
 class DescribeNotesSlide(object):
-
     def it_can_clone_the_notes_master_placeholders(self, clone_fixture):
         notes_slide, notes_master_, clone_placeholder_, calls = clone_fixture
         notes_slide.clone_master_placeholders(notes_master_)
@@ -193,42 +197,40 @@ class DescribeNotesSlide(object):
     # fixtures -------------------------------------------------------
 
     @pytest.fixture
-    def clone_fixture(self, notes_master_, clone_placeholder_, shapes_prop_,
-                      shapes_):
+    def clone_fixture(self, notes_master_, clone_placeholder_, shapes_prop_, shapes_):
         notes_slide = NotesSlide(None, None)
         placeholders = notes_master_.placeholders = (
-            BaseShape(element('p:sp/p:nvSpPr/p:nvPr/p:ph{type=body}'), None),
-            BaseShape(element('p:sp/p:nvSpPr/p:nvPr/p:ph{type=dt}'), None),
+            BaseShape(element("p:sp/p:nvSpPr/p:nvPr/p:ph{type=body}"), None),
+            BaseShape(element("p:sp/p:nvSpPr/p:nvPr/p:ph{type=dt}"), None),
         )
         calls = [call(placeholders[0])]
         shapes_.clone_placeholder = clone_placeholder_
         return notes_slide, notes_master_, clone_placeholder_, calls
 
-    @pytest.fixture(params=[
-        (('SLIDE_IMAGE', 'BODY', 'SLIDE_NUMBER'), 1),
-        (('DATE', 'SLIDE_IMAGE', 'FOOTER'), None),
-
-    ])
+    @pytest.fixture(
+        params=[
+            (("SLIDE_IMAGE", "BODY", "SLIDE_NUMBER"), 1),
+            (("DATE", "SLIDE_IMAGE", "FOOTER"), None),
+        ]
+    )
     def notes_ph_fixture(self, request, placeholders_prop_):
         type_names, match = request.param
         notes_slide = NotesSlide(None, None)
         placeholders_ = []
         for type_name in type_names:
             placeholder_ = instance_mock(
-                request, NotesSlidePlaceholder,
-                name='%s-placeholder' % type_name
-            )
-            placeholder_.placeholder_format.type = getattr(
-                PP_PLACEHOLDER, type_name
+                request, NotesSlidePlaceholder, name="%s-placeholder" % type_name
             )
+            placeholder_.placeholder_format.type = getattr(PP_PLACEHOLDER, type_name)
             placeholders_.append(placeholder_)
         placeholders_prop_.return_value = placeholders_
         expected_value = None if match is None else placeholders_[match]
         return notes_slide, expected_value
 
     @pytest.fixture(params=[True, False])
-    def notes_tf_fixture(self, request, notes_placeholder_prop_,
-                         placeholder_, text_frame_):
+    def notes_tf_fixture(
+        self, request, notes_placeholder_prop_, placeholder_, text_frame_
+    ):
         has_text_frame = request.param
         notes_slide = NotesSlide(None, None)
         if has_text_frame:
@@ -242,23 +244,23 @@ class DescribeNotesSlide(object):
 
     @pytest.fixture
     def placeholders_fixture(self, NotesSlidePlaceholders_, placeholders_):
-        notes = element('p:notes/p:cSld/p:spTree')
+        notes = element("p:notes/p:cSld/p:spTree")
         notes_slide = NotesSlide(notes, None)
-        spTree = notes.xpath('//p:spTree')[0]
+        spTree = notes.xpath("//p:spTree")[0]
         return notes_slide, NotesSlidePlaceholders_, spTree, placeholders_
 
     @pytest.fixture
     def shapes_fixture(self, NotesSlideShapes_, shapes_):
-        notes = element('p:notes/p:cSld/p:spTree')
+        notes = element("p:notes/p:cSld/p:spTree")
         notes_slide = NotesSlide(notes, None)
-        spTree = notes.xpath('//p:spTree')[0]
+        spTree = notes.xpath("//p:spTree")[0]
         return notes_slide, NotesSlideShapes_, spTree, shapes_
 
     # fixture components ---------------------------------------------
 
     @pytest.fixture
     def clone_placeholder_(self, request):
-        return method_mock(request, NotesSlideShapes, 'clone_placeholder')
+        return method_mock(request, NotesSlideShapes, "clone_placeholder")
 
     @pytest.fixture
     def notes_master_(self, request):
@@ -267,22 +269,18 @@ class DescribeNotesSlide(object):
     @pytest.fixture
     def notes_placeholder_prop_(self, request, placeholder_):
         return property_mock(
-            request, NotesSlide, 'notes_placeholder',
-            return_value=placeholder_
+            request, NotesSlide, "notes_placeholder", return_value=placeholder_
         )
 
     @pytest.fixture
     def NotesSlidePlaceholders_(self, request, placeholders_):
         return class_mock(
-            request, 'pptx.slide.NotesSlidePlaceholders',
-            return_value=placeholders_
+            request, "pptx.slide.NotesSlidePlaceholders", return_value=placeholders_
         )
 
     @pytest.fixture
     def NotesSlideShapes_(self, request, shapes_):
-        return class_mock(
-            request, 'pptx.slide.NotesSlideShapes', return_value=shapes_
-        )
+        return class_mock(request, "pptx.slide.NotesSlideShapes", return_value=shapes_)
 
     @pytest.fixture
     def placeholder_(self, request):
@@ -295,7 +293,7 @@ class DescribeNotesSlide(object):
     @pytest.fixture
     def placeholders_prop_(self, request, placeholders_):
         return property_mock(
-            request, NotesSlide, 'placeholders', return_value=placeholders_
+            request, NotesSlide, "placeholders", return_value=placeholders_
         )
 
     @pytest.fixture
@@ -304,9 +302,7 @@ class DescribeNotesSlide(object):
 
     @pytest.fixture
     def shapes_prop_(self, request, shapes_):
-        return property_mock(
-            request, NotesSlide, 'shapes', return_value=shapes_
-        )
+        return property_mock(request, NotesSlide, "shapes", return_value=shapes_)
 
     @pytest.fixture
     def text_frame_(self, request):
@@ -314,7 +310,6 @@ class DescribeNotesSlide(object):
 
 
 class DescribeSlide(object):
-
     def it_is_a_BaseSlide_subclass(self, subclass_fixture):
         slide = subclass_fixture
         assert isinstance(slide, _BaseSlide)
@@ -347,9 +342,7 @@ class DescribeSlide(object):
         assert shapes is shapes_
 
     def it_provides_access_to_its_placeholders(self, placeholders_fixture):
-        slide, SlidePlaceholders_, spTree, placeholders_ = (
-            placeholders_fixture
-        )
+        slide, SlidePlaceholders_, spTree, placeholders_ = placeholders_fixture
         placeholders = slide.placeholders
         SlidePlaceholders_.assert_called_once_with(spTree, slide)
         assert placeholders is placeholders_
@@ -370,10 +363,7 @@ class DescribeSlide(object):
         _BaseSlide_background_.return_value = background_
         return slide, _BaseSlide_background_, background_
 
-    @pytest.fixture(params=[
-        ('p:sld/p:cSld',      True),
-        ('p:sld/p:cSld/p:bg', False),
-    ])
+    @pytest.fixture(params=[("p:sld/p:cSld", True), ("p:sld/p:cSld/p:bg", False)])
     def follow_get_fixture(self, request):
         pSld_cxml, expected_value = request.param
         slide = Slide(element(pSld_cxml), None)
@@ -400,15 +390,15 @@ class DescribeSlide(object):
 
     @pytest.fixture
     def placeholders_fixture(self, SlidePlaceholders_, placeholders_):
-        sld = element('p:sld/p:cSld/p:spTree')
+        sld = element("p:sld/p:cSld/p:spTree")
         slide = Slide(sld, None)
-        spTree = sld.xpath('//p:spTree')[0]
+        spTree = sld.xpath("//p:spTree")[0]
         return slide, SlidePlaceholders_, spTree, placeholders_
 
     @pytest.fixture
     def shapes_fixture(self, SlideShapes_, shapes_):
-        sld = element('p:sld/p:cSld/p:spTree')
-        spTree = sld.xpath('//p:spTree')[0]
+        sld = element("p:sld/p:cSld/p:spTree")
+        spTree = sld.xpath("//p:spTree")[0]
         slide = Slide(sld, None)
         return slide, SlideShapes_, spTree, shapes_
 
@@ -427,7 +417,7 @@ class DescribeSlide(object):
 
     @pytest.fixture
     def _BaseSlide_background_(self, request):
-        return property_mock(request, _BaseSlide, 'background')
+        return property_mock(request, _BaseSlide, "background")
 
     @pytest.fixture
     def background_(self, request):
@@ -439,9 +429,7 @@ class DescribeSlide(object):
 
     @pytest.fixture
     def part_prop_(self, request, slide_part_):
-        return property_mock(
-            request, Slide, 'part', return_value=slide_part_
-        )
+        return property_mock(request, Slide, "part", return_value=slide_part_)
 
     @pytest.fixture
     def placeholders_(self, request):
@@ -450,15 +438,12 @@ class DescribeSlide(object):
     @pytest.fixture
     def SlidePlaceholders_(self, request, placeholders_):
         return class_mock(
-            request, 'pptx.slide.SlidePlaceholders',
-            return_value=placeholders_
+            request, "pptx.slide.SlidePlaceholders", return_value=placeholders_
         )
 
     @pytest.fixture
     def SlideShapes_(self, request, shapes_):
-        return class_mock(
-            request, 'pptx.slide.SlideShapes', return_value=shapes_
-        )
+        return class_mock(request, "pptx.slide.SlideShapes", return_value=shapes_)
 
     @pytest.fixture
     def shapes_(self, request):
@@ -474,7 +459,6 @@ class DescribeSlide(object):
 
 
 class DescribeSlides(object):
-
     def it_supports_indexed_access(self, getitem_fixture):
         slides, prs_part_, rId, slide_ = getitem_fixture
         slide = slides[0]
@@ -527,69 +511,68 @@ class DescribeSlides(object):
 
     @pytest.fixture
     def add_fixture(self, slide_layout_, part_prop_, slide_):
-        slides = Slides(element('p:sldIdLst/p:sldId{r:id=rId1}'), None)
+        slides = Slides(element("p:sldIdLst/p:sldId{r:id=rId1}"), None)
         part_ = part_prop_.return_value
         clone_layout_placeholders_ = slide_.shapes.clone_layout_placeholders
-        expected_xml = xml(
-            'p:sldIdLst/(p:sldId{r:id=rId1},p:sldId{r:id=rId2,id=256})'
-        )
-        part_.add_slide.return_value = 'rId2', slide_
+        expected_xml = xml("p:sldIdLst/(p:sldId{r:id=rId1},p:sldId{r:id=rId2,id=256})")
+        part_.add_slide.return_value = "rId2", slide_
         return (
-            slides, slide_layout_, part_, clone_layout_placeholders_,
-            expected_xml, slide_
+            slides,
+            slide_layout_,
+            part_,
+            clone_layout_placeholders_,
+            expected_xml,
+            slide_,
         )
 
     @pytest.fixture(params=[True, False])
     def get_fixture(self, request, part_prop_, prs_part_, slide_):
         found = request.param
         slides = Slides(None, None)
-        slide_id, default = 256, 'foobar'
+        slide_id, default = 256, "foobar"
         expected_value = slide_ if found else default
         prs_part_.get_slide.return_value = slide_ if found else None
         return slides, slide_id, default, prs_part_, expected_value
 
     @pytest.fixture
     def getitem_fixture(self, prs_part_, slide_, part_prop_):
-        sldIdLst = element('p:sldIdLst/p:sldId{r:id=rId1}')
+        sldIdLst = element("p:sldIdLst/p:sldId{r:id=rId1}")
         slides = Slides(sldIdLst, None)
         prs_part_.related_slide.return_value = slide_
-        return slides, prs_part_, 'rId1', slide_
+        return slides, prs_part_, "rId1", slide_
 
     @pytest.fixture
     def getitem_raises_fixture(self):
-        sldIdLst = element('p:sldIdLst/p:sldId{r:id=rId1}')
+        sldIdLst = element("p:sldIdLst/p:sldId{r:id=rId1}")
         slides = Slides(sldIdLst, None)
         return slides
 
     @pytest.fixture(params=[0, 1])
     def index_fixture(self, request, part_prop_):
         idx = request.param
-        sldIdLst = element('p:sldIdLst/(p:sldId{r:id=a},p:sldId{r:id=b})')
+        sldIdLst = element("p:sldIdLst/(p:sldId{r:id=a},p:sldId{r:id=b})")
         slides = Slides(sldIdLst, None)
-        _slides = [
-            Slide(element('p:sld'), None),
-            Slide(element('p:sld'), None)
-        ]
-        part_prop_.return_value.related_slide.side_effect = (
-            _slides
-        )
+        _slides = [Slide(element("p:sld"), None), Slide(element("p:sld"), None)]
+        part_prop_.return_value.related_slide.side_effect = _slides
         return slides, _slides[idx], idx
 
     @pytest.fixture
     def iter_fixture(self, part_prop_, slide_):
-        sldIdLst = element('p:sldIdLst/(p:sldId{r:id=a},p:sldId{r:id=b})')
+        sldIdLst = element("p:sldIdLst/(p:sldId{r:id=a},p:sldId{r:id=b})")
         slides = Slides(sldIdLst, None)
         related_slide_ = part_prop_.return_value.related_slide
         related_slide_.return_value = slide_
-        calls = [call('a'), call('b')]
+        calls = [call("a"), call("b")]
         _slides = [slide_, slide_]
         return slides, related_slide_, calls, _slides
 
-    @pytest.fixture(params=[
-        ('p:sldIdLst',                                   0),
-        ('p:sldIdLst/p:sldId{r:id=a}',                   1),
-        ('p:sldIdLst/(p:sldId{r:id=a},p:sldId{r:id=b})', 2),
-    ])
+    @pytest.fixture(
+        params=[
+            ("p:sldIdLst", 0),
+            ("p:sldIdLst/p:sldId{r:id=a}", 1),
+            ("p:sldIdLst/(p:sldId{r:id=a},p:sldId{r:id=b})", 2),
+        ]
+    )
     def len_fixture(self, request):
         sldIdLst_cxml, expected_value = request.param
         slides = Slides(element(sldIdLst_cxml), None)
@@ -597,15 +580,15 @@ class DescribeSlides(object):
 
     @pytest.fixture
     def raises_fixture(self):
-        slides = Slides(element('p:sldIdLst'), None)
-        slide = Slide(element('p:sld'), None)
+        slides = Slides(element("p:sldIdLst"), None)
+        slide = Slide(element("p:sld"), None)
         return slides, slide
 
     # fixture components ---------------------------------------------
 
     @pytest.fixture
     def part_prop_(self, request, prs_part_):
-        return property_mock(request, Slides, 'part', return_value=prs_part_)
+        return property_mock(request, Slides, "part", return_value=prs_part_)
 
     @pytest.fixture
     def prs_part_(self, request):
@@ -621,7 +604,6 @@ class DescribeSlides(object):
 
 
 class DescribeSlideLayout(object):
-
     def it_is_a_BaseSlide_subclass(self):
         slide_layout = SlideLayout(None, None)
         assert isinstance(slide_layout, _BaseSlide)
@@ -632,10 +614,10 @@ class DescribeSlideLayout(object):
         assert cloneable == expected_placeholders
 
     def it_provides_access_to_its_placeholders(
-            self, LayoutPlaceholders_, placeholders_
+        self, LayoutPlaceholders_, placeholders_
     ):
-        sldLayout = element('p:sldLayout/p:cSld/p:spTree')
-        spTree = sldLayout.xpath('//p:spTree')[0]
+        sldLayout = element("p:sldLayout/p:cSld/p:spTree")
+        spTree = sldLayout.xpath("//p:spTree")[0]
         slide_layout = SlideLayout(sldLayout, None)
 
         placeholders = slide_layout.placeholders
@@ -644,8 +626,8 @@ class DescribeSlideLayout(object):
         assert placeholders is placeholders_
 
     def it_provides_access_to_its_shapes(self, LayoutShapes_, shapes_):
-        sldLayout = element('p:sldLayout/p:cSld/p:spTree')
-        spTree = sldLayout.xpath('//p:spTree')[0]
+        sldLayout = element("p:sldLayout/p:cSld/p:spTree")
+        spTree = sldLayout.xpath("//p:spTree")[0]
         slide_layout = SlideLayout(sldLayout, None)
 
         shapes = slide_layout.shapes
@@ -662,13 +644,13 @@ class DescribeSlideLayout(object):
         assert slide_master is slide_master_
 
     def it_knows_which_slides_are_based_on_it(
-            self,
-            used_by_fixture,
-            part_prop_,
-            slide_layout_part_,
-            package_,
-            presentation_part_,
-            presentation_,
+        self,
+        used_by_fixture,
+        part_prop_,
+        slide_layout_part_,
+        package_,
+        presentation_part_,
+        presentation_,
     ):
         presentation_, slide_layout, expected_value = used_by_fixture
         part_prop_.return_value = slide_layout_part_
@@ -682,22 +664,23 @@ class DescribeSlideLayout(object):
 
     # fixtures -------------------------------------------------------
 
-    @pytest.fixture(params=[
-        ((PP_PLACEHOLDER.TITLE,        PP_PLACEHOLDER.BODY),   (0, 1)),
-        ((PP_PLACEHOLDER.TITLE,        PP_PLACEHOLDER.DATE),   (0,)),
-        ((PP_PLACEHOLDER.FOOTER,       PP_PLACEHOLDER.OBJECT), (1,)),
-        ((PP_PLACEHOLDER.SLIDE_NUMBER, PP_PLACEHOLDER.FOOTER), ()),
-    ])
+    @pytest.fixture(
+        params=[
+            ((PP_PLACEHOLDER.TITLE, PP_PLACEHOLDER.BODY), (0, 1)),
+            ((PP_PLACEHOLDER.TITLE, PP_PLACEHOLDER.DATE), (0,)),
+            ((PP_PLACEHOLDER.FOOTER, PP_PLACEHOLDER.OBJECT), (1,)),
+            ((PP_PLACEHOLDER.SLIDE_NUMBER, PP_PLACEHOLDER.FOOTER), ()),
+        ]
+    )
     def cloneable_fixture(
-            self, request, placeholders_prop_, placeholder_, placeholder_2_):
+        self, request, placeholders_prop_, placeholder_, placeholder_2_
+    ):
         ph_types, expected_indices = request.param
         slide_layout = SlideLayout(None, None)
         placeholder_.element.ph_type = ph_types[0]
         placeholder_2_.element.ph_type = ph_types[1]
         _placeholders = (placeholder_, placeholder_2_)
-        expected_placeholders = [
-            _placeholders[idx] for idx in expected_indices
-        ]
+        expected_placeholders = [_placeholders[idx] for idx in expected_indices]
         placeholders_prop_.return_value = _placeholders
         return slide_layout, expected_placeholders
 
@@ -717,15 +700,12 @@ class DescribeSlideLayout(object):
     @pytest.fixture
     def LayoutPlaceholders_(self, request, placeholders_):
         return class_mock(
-            request, 'pptx.slide.LayoutPlaceholders',
-            return_value=placeholders_
+            request, "pptx.slide.LayoutPlaceholders", return_value=placeholders_
         )
 
     @pytest.fixture
     def LayoutShapes_(self, request, shapes_):
-        return class_mock(
-            request, 'pptx.slide.LayoutShapes', return_value=shapes_
-        )
+        return class_mock(request, "pptx.slide.LayoutShapes", return_value=shapes_)
 
     @pytest.fixture
     def package_(self, request):
@@ -734,7 +714,7 @@ class DescribeSlideLayout(object):
     @pytest.fixture
     def part_prop_(self, request, slide_layout_part_):
         return property_mock(
-            request, SlideLayout, 'part', return_value=slide_layout_part_
+            request, SlideLayout, "part", return_value=slide_layout_part_
         )
 
     @pytest.fixture
@@ -752,7 +732,7 @@ class DescribeSlideLayout(object):
     @pytest.fixture
     def placeholders_prop_(self, request, placeholders_):
         return property_mock(
-            request, SlideLayout, 'placeholders', return_value=placeholders_
+            request, SlideLayout, "placeholders", return_value=placeholders_
         )
 
     @pytest.fixture
@@ -785,18 +765,17 @@ class DescribeSlideLayout(object):
 
 
 class DescribeSlideLayouts(object):
-
     def it_supports_len(self, len_fixture):
         slide_layouts, expected_value = len_fixture
         assert len(slide_layouts) == expected_value
 
     def it_can_iterate_its_slide_layouts(self, part_prop_, slide_master_part_):
         sldLayoutIdLst = element(
-            'p:sldLayoutIdLst/(p:sldLayoutId{r:id=a},p:sldLayoutId{r:id=b})'
+            "p:sldLayoutIdLst/(p:sldLayoutId{r:id=a},p:sldLayoutId{r:id=b})"
         )
         _slide_layouts = [
-            SlideLayout(element('p:sldLayout'), None),
-            SlideLayout(element('p:sldLayout'), None),
+            SlideLayout(element("p:sldLayout"), None),
+            SlideLayout(element("p:sldLayout"), None),
         ]
         part_prop_.return_value = slide_master_part_
         related_slide_layout_ = slide_master_part_.related_slide_layout
@@ -805,14 +784,14 @@ class DescribeSlideLayouts(object):
 
         slide_layout_lst = [sl for sl in slide_layouts]
 
-        assert related_slide_layout_.call_args_list == [call('a'), call('b')]
+        assert related_slide_layout_.call_args_list == [call("a"), call("b")]
         assert slide_layout_lst == _slide_layouts
 
     def it_supports_indexed_access(self, slide_layout_, part_prop_, slide_master_part_):
         part_prop_.return_value = slide_master_part_
         slide_master_part_.related_slide_layout.return_value = slide_layout_
         slide_layouts = SlideLayouts(
-            element('p:sldLayoutIdLst/p:sldLayoutId{r:id=rId1}'), None
+            element("p:sldLayoutIdLst/p:sldLayoutId{r:id=rId1}"), None
         )
 
         slide_layout = slide_layouts[0]
@@ -822,13 +801,13 @@ class DescribeSlideLayouts(object):
 
     def but_it_raises_on_index_out_of_range(self, part_prop_):
         slide_layouts = SlideLayouts(
-            element('p:sldLayoutIdLst/p:sldLayoutId{r:id=rId1}'), None
+            element("p:sldLayoutIdLst/p:sldLayoutId{r:id=rId1}"), None
         )
         with pytest.raises(IndexError):
             slide_layouts[1]
 
     def it_can_find_a_slide_layout_by_name(
-            self, _iter_, slide_layout_, slide_layout_2_
+        self, _iter_, slide_layout_, slide_layout_2_
     ):
         _iter_.return_value = iter((slide_layout_, slide_layout_2_))
         slide_layout_2_.name = "pick me!"
@@ -839,7 +818,7 @@ class DescribeSlideLayouts(object):
         assert slide_layout is slide_layout_2_
 
     def but_it_returns_the_default_value_when_no_layout_has_that_name(
-            self, _iter_, slide_layout_, slide_layout_2_
+        self, _iter_, slide_layout_, slide_layout_2_
     ):
         _iter_.return_value = iter((slide_layout_, slide_layout_2_))
         slide_layout_2_.name = "not the droid you're looking for"
@@ -851,10 +830,10 @@ class DescribeSlideLayouts(object):
 
         # ---but default can be specified---
         slide_layout = slide_layouts.get_by_name("pick me!", "default-value")
-        assert slide_layout is "default-value"
+        assert slide_layout == "default-value"
 
     def it_knows_the_index_of_each_of_its_slide_layouts(
-            self, _iter_, slide_layout_, slide_layout_2_
+        self, _iter_, slide_layout_, slide_layout_2_
     ):
         _iter_.return_value = iter((slide_layout_, slide_layout_2_))
         slide_layouts = SlideLayouts(None, None)
@@ -864,7 +843,7 @@ class DescribeSlideLayouts(object):
         assert index == 1
 
     def but_it_raises_on_slide_layout_not_in_collection(
-            self, _iter_, slide_layout_, slide_layout_2_
+        self, _iter_, slide_layout_, slide_layout_2_
     ):
         _iter_.return_value = iter((slide_layout_,))
         slide_layouts = SlideLayouts(None, None)
@@ -874,7 +853,7 @@ class DescribeSlideLayouts(object):
         assert str(e.value) == "layout not in this SlideLayouts collection"
 
     def it_can_remove_an_unused_slide_layout(
-            self, slide_layout_, index_, slide_master_, slide_master_part_
+        self, slide_layout_, index_, slide_master_, slide_master_part_
     ):
         slide_layout_.used_by_slides = ()
         index_.return_value = 0
@@ -893,7 +872,7 @@ class DescribeSlideLayouts(object):
         slide_master_part_.drop_rel.assert_called_once_with("rId1")
 
     def but_it_raises_on_attempt_to_remove_slide_layout_in_use(
-            self, slide_layout_, slide_
+        self, slide_layout_, slide_
     ):
         slide_layout_.used_by_slides = (slide_,)
         slide_layouts = SlideLayouts(None, None)
@@ -903,11 +882,13 @@ class DescribeSlideLayouts(object):
 
     # fixtures -------------------------------------------------------
 
-    @pytest.fixture(params=[
-        ('p:sldLayoutIdLst',                               0),
-        ('p:sldLayoutIdLst/p:sldLayoutId',                 1),
-        ('p:sldLayoutIdLst/(p:sldLayoutId,p:sldLayoutId)', 2),
-    ])
+    @pytest.fixture(
+        params=[
+            ("p:sldLayoutIdLst", 0),
+            ("p:sldLayoutIdLst/p:sldLayoutId", 1),
+            ("p:sldLayoutIdLst/(p:sldLayoutId,p:sldLayoutId)", 2),
+        ]
+    )
     def len_fixture(self, request):
         sldLayoutIdLst_cxml, expected_value = request.param
         slide_layouts = SlideLayouts(element(sldLayoutIdLst_cxml), None)
@@ -925,7 +906,7 @@ class DescribeSlideLayouts(object):
 
     @pytest.fixture
     def part_prop_(self, request):
-        return property_mock(request, SlideLayouts, 'part')
+        return property_mock(request, SlideLayouts, "part")
 
     @pytest.fixture
     def slide_(self, request):
@@ -949,15 +930,12 @@ class DescribeSlideLayouts(object):
 
 
 class DescribeSlideMaster(object):
-
     def it_is_a_BaseMaster_subclass(self, subclass_fixture):
         slide_master = subclass_fixture
         assert isinstance(slide_master, _BaseMaster)
 
     def it_provides_access_to_its_slide_layouts(self, layouts_fixture):
-        slide_master, SlideLayouts_, sldLayoutIdLst, slide_layouts_ = (
-            layouts_fixture
-        )
+        slide_master, SlideLayouts_, sldLayoutIdLst, slide_layouts_ = layouts_fixture
         slide_layouts = slide_master.slide_layouts
         SlideLayouts_.assert_called_once_with(sldLayoutIdLst, slide_master)
         assert slide_layouts is slide_layouts_
@@ -966,7 +944,7 @@ class DescribeSlideMaster(object):
 
     @pytest.fixture
     def layouts_fixture(self, SlideLayouts_, slide_layouts_):
-        sldMaster = element('p:sldMaster/p:sldLayoutIdLst')
+        sldMaster = element("p:sldMaster/p:sldLayoutIdLst")
         slide_master = SlideMaster(sldMaster, None)
         sldMasterIdLst = sldMaster.sldLayoutIdLst
         return slide_master, SlideLayouts_, sldMasterIdLst, slide_layouts_
@@ -980,7 +958,7 @@ class DescribeSlideMaster(object):
     @pytest.fixture
     def SlideLayouts_(self, request, slide_layouts_):
         return class_mock(
-            request, 'pptx.slide.SlideLayouts', return_value=slide_layouts_
+            request, "pptx.slide.SlideLayouts", return_value=slide_layouts_
         )
 
     @pytest.fixture
@@ -989,15 +967,12 @@ class DescribeSlideMaster(object):
 
 
 class DescribeSlideMasters(object):
-
     def it_knows_how_many_masters_it_contains(self, len_fixture):
         slide_masters, expected_value = len_fixture
         assert len(slide_masters) == expected_value
 
     def it_can_iterate_the_slide_masters(self, iter_fixture):
-        slide_masters, related_slide_master_, calls, expected_values = (
-            iter_fixture
-        )
+        slide_masters, related_slide_master_, calls, expected_values = iter_fixture
         _slide_masters = [sm for sm in slide_masters]
         assert related_slide_master_.call_args_list == calls
         assert _slide_masters == expected_values
@@ -1018,37 +993,37 @@ class DescribeSlideMasters(object):
     @pytest.fixture
     def getitem_fixture(self, part_, slide_master_, part_prop_):
         slide_masters = SlideMasters(
-            element('p:sldMasterIdLst/p:sldMasterId{r:id=rId1}'), None
+            element("p:sldMasterIdLst/p:sldMasterId{r:id=rId1}"), None
         )
         part_.related_slide_master.return_value = slide_master_
-        return slide_masters, part_, slide_master_, 'rId1'
+        return slide_masters, part_, slide_master_, "rId1"
 
     @pytest.fixture
     def getitem_raises_fixture(self, part_prop_):
-        return SlideMasters(
-            element('p:sldMasterIdLst/p:sldMasterId{r:id=rId1}'), None
-        )
+        return SlideMasters(element("p:sldMasterIdLst/p:sldMasterId{r:id=rId1}"), None)
 
     @pytest.fixture
     def iter_fixture(self, part_prop_):
         sldMasterIdLst = element(
-            'p:sldMasterIdLst/(p:sldMasterId{r:id=a},p:sldMasterId{r:id=b})'
+            "p:sldMasterIdLst/(p:sldMasterId{r:id=a},p:sldMasterId{r:id=b})"
         )
         slide_masters = SlideMasters(sldMasterIdLst, None)
         related_slide_master_ = part_prop_.return_value.related_slide_master
-        calls = [call('a'), call('b')]
+        calls = [call("a"), call("b")]
         _slide_masters = [
-            SlideMaster(element('p:sldMaster'), None),
-            SlideMaster(element('p:sldMaster'), None)
+            SlideMaster(element("p:sldMaster"), None),
+            SlideMaster(element("p:sldMaster"), None),
         ]
         related_slide_master_.side_effect = _slide_masters
         return slide_masters, related_slide_master_, calls, _slide_masters
 
-    @pytest.fixture(params=[
-        ('p:sldMasterIdLst',                               0),
-        ('p:sldMasterIdLst/p:sldMasterId',                 1),
-        ('p:sldMasterIdLst/(p:sldMasterId,p:sldMasterId)', 2),
-    ])
+    @pytest.fixture(
+        params=[
+            ("p:sldMasterIdLst", 0),
+            ("p:sldMasterIdLst/p:sldMasterId", 1),
+            ("p:sldMasterIdLst/(p:sldMasterId,p:sldMasterId)", 2),
+        ]
+    )
     def len_fixture(self, request):
         sldMasterIdLst_cxml, expected_value = request.param
         slide_masters = SlideMasters(element(sldMasterIdLst_cxml), None)
@@ -1062,9 +1037,7 @@ class DescribeSlideMasters(object):
 
     @pytest.fixture
     def part_prop_(self, request, part_):
-        return property_mock(
-            request, SlideMasters, 'part', return_value=part_
-        )
+        return property_mock(request, SlideMasters, "part", return_value=part_)
 
     @pytest.fixture
     def slide_master_(self, request):
@@ -1072,7 +1045,6 @@ class DescribeSlideMasters(object):
 
 
 class Describe_Background(object):
-
     def it_provides_access_to_its_fill(self, fill_fixture):
         background, cSld, expected_xml = fill_fixture[:3]
         from_fill_parent_, fill_ = fill_fixture[3:]
@@ -1080,21 +1052,21 @@ class Describe_Background(object):
         fill = background.fill
 
         assert cSld.xml == expected_xml
-        from_fill_parent_.assert_called_once_with(
-            cSld.xpath('p:bg/p:bgPr')[0]
-        )
+        from_fill_parent_.assert_called_once_with(cSld.xpath("p:bg/p:bgPr")[0])
         assert fill is fill_
 
     # fixtures -------------------------------------------------------
 
-    @pytest.fixture(params=[
-        ('p:cSld{a:b=c}',
-         'p:cSld{a:b=c}/p:bg/p:bgPr/(a:noFill,a:effectLst)'),
-        ('p:cSld{a:b=c}/p:bg/p:bgRef',
-         'p:cSld{a:b=c}/p:bg/p:bgPr/(a:noFill,a:effectLst)'),
-        ('p:cSld/p:bg/p:bgPr/a:solidFill',
-         'p:cSld/p:bg/p:bgPr/a:solidFill'),
-    ])
+    @pytest.fixture(
+        params=[
+            ("p:cSld{a:b=c}", "p:cSld{a:b=c}/p:bg/p:bgPr/(a:noFill,a:effectLst)"),
+            (
+                "p:cSld{a:b=c}/p:bg/p:bgRef",
+                "p:cSld{a:b=c}/p:bg/p:bgPr/(a:noFill,a:effectLst)",
+            ),
+            ("p:cSld/p:bg/p:bgPr/a:solidFill", "p:cSld/p:bg/p:bgPr/a:solidFill"),
+        ]
+    )
     def fill_fixture(self, request, from_fill_parent_, fill_):
         cSld_xml, expected_cxml = request.param
         cSld = element(cSld_xml)
@@ -1113,4 +1085,4 @@ class Describe_Background(object):
 
     @pytest.fixture
     def from_fill_parent_(self, request):
-        return method_mock(request, FillFormat, 'from_fill_parent')
+        return method_mock(request, FillFormat, "from_fill_parent")
